@@ -1,16 +1,17 @@
 #!/usr/bin/python3
 
-import os
-
-from lintian_brush import certainty_to_confidence, certainty_sufficient
-from lintian_brush.copyright import update_copyright, NotMachineReadableError
+from lintian_brush import certainty_to_confidence
+from lintian_brush.copyright import CopyrightUpdater, NotMachineReadableError
+from lintian_brush.fixer import (
+    meets_minimum_certainty,
+    trust_package,
+    )
 from lintian_brush.upstream_metadata import (
     guess_upstream_metadata_items,
     UpstreamDatum,
     )
 
 
-minimum_certainty = os.environ.get('MINIMUM_CERTAINTY')
 fields = []
 achieved_certainty = []
 
@@ -29,8 +30,8 @@ def add_upstream_metadata(copyright):
         upstream_metadata = {
             k: UpstreamDatum(k, v, 'certain') for (k, v) in code.items()}
     for datum in guess_upstream_metadata_items(
-            '.', trust_package=(os.environ.get('TRUST_PACKAGE') == 'true')):
-        if not certainty_sufficient(datum.certainty, minimum_certainty):
+            '.', trust_package=trust_package()):
+        if not meets_minimum_certainty(datum.certainty):
             continue
         if (datum.field not in upstream_metadata or
                 upstream_metadata[datum.field].certainty != 'certain'):
@@ -63,11 +64,15 @@ def add_upstream_metadata(copyright):
 
 
 try:
-    update_copyright(add_upstream_metadata)
+    with CopyrightUpdater() as updater:
+        add_upstream_metadata(updater.copyright)
 except (FileNotFoundError, NotMachineReadableError):
     pass
 
-print('Set fields %s in debian/copyright.' % ', '.join(fields))
+if len(fields) == 1:
+    print('Set field %s in debian/copyright.' % ', '.join(fields))
+else:
+    print('Set fields %s in debian/copyright.' % ', '.join(fields))
 if achieved_certainty:
     print('Certainty: %s' %
           min(achieved_certainty, key=certainty_to_confidence))
