@@ -5,7 +5,7 @@ import re
 import socket
 import sys
 from lintian_brush import USER_AGENT, DEFAULT_URLLIB_TIMEOUT
-from lintian_brush.control import update_control
+from lintian_brush.control import ControlUpdater
 from lintian_brush.fixer import net_access_allowed
 from lintian_brush.salsa import (
     determine_browser_url as determine_salsa_browser_url,
@@ -86,7 +86,7 @@ def find_new_urls(vcs_type, vcs_url, package, maintainer_email,
             response = urlopen(
                 Request(vcs_url, headers=headers),
                 timeout=DEFAULT_URLLIB_TIMEOUT)
-        except urllib.error.HTTPError:
+        except (urllib.error.HTTPError, urllib.error.URLError):
             pass
         except socket.timeout:
             pass
@@ -100,9 +100,8 @@ def find_new_urls(vcs_type, vcs_url, package, maintainer_email,
 
     # If possible, we use vcswatch to find the VCS repository URL
     if net_access:
-        loop = asyncio.get_event_loop()
         try:
-            (vcs_type, vcs_url, vcs_browser) = loop.run_until_complete(
+            (vcs_type, vcs_url, vcs_browser) = asyncio.run(
                 retrieve_vcswatch_urls(package))
         except VcsWatchError as e:
             sys.stderr.write('vcswatch URL unusable: %s\n' % e.args[0])
@@ -187,6 +186,7 @@ def migrate_from_obsolete_infra(control):
             pass
 
 
-update_control(source_package_cb=migrate_from_obsolete_infra)
+with ControlUpdater() as updater:
+    migrate_from_obsolete_infra(updater.source)
 if fixed_tags:
     print("Fixed-Lintian-Tags: " + ", ".join(sorted(fixed_tags)))
