@@ -52,7 +52,7 @@ from debian.deb822 import Deb822
 from .reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 69)
+__version__ = (0, 70)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'confident', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -558,7 +558,7 @@ def only_changes_last_changelog_block(
 
 
 def reset_tree(local_tree: WorkingTree, dirty_tracker=None,
-               subpath: str = '.') -> None:
+               subpath: str = '') -> None:
     """Reset a tree back to its basis tree.
 
     This will leave ignored and detritus files alone.
@@ -571,7 +571,7 @@ def reset_tree(local_tree: WorkingTree, dirty_tracker=None,
     if dirty_tracker and not dirty_tracker.is_dirty():
         return
     revert(local_tree, local_tree.branch.basis_tree(),
-           [subpath] if subpath != '.' else None)
+           [subpath] if subpath not in ('.', '') else None)
     deletables = list(iter_deletables(
         local_tree, unknown=True, ignored=False, detritus=False))
     delete_items(deletables)
@@ -958,3 +958,18 @@ def min_certainty(certainties: Sequence[str]) -> str:
     return confidence_to_certainty(
         max([certainty_to_confidence(c)
             for c in certainties] + [0]))
+
+
+def load_renamed_tags():
+    import json
+    path = os.path.abspath(os.path.join(
+        os.path.dirname(__file__), '..', 'renamed-tags.json'))
+    if not os.path.isfile(path):
+        import pkg_resources
+        path = pkg_resources.resource_filename(
+            __name__, 'lintian-brush/renamed-tags.json')
+        if not os.path.isfile(path):
+            # Urgh.
+            path = '/usr/share/lintian-brush/renamed-tags.json'
+    with open(path, 'rb') as f:
+        return json.load(f)
