@@ -26,12 +26,6 @@ import distro_info
 
 from breezy.branch import Branch
 from breezy.workingtree import WorkingTree
-import locale
-locale.setlocale(locale.LC_ALL, '')
-# Use better default than ascii with posix filesystems that deal in bytes
-# natively even when the C locale or no locale at all is given. Note that
-# we need an immortal string for the hack, hence the lack of a hyphen.
-sys._brz_default_fs_enc = "utf8"   # type: ignore
 
 import breezy  # noqa: E402
 from breezy.errors import (  # noqa: E402
